@@ -320,6 +320,10 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terrag
     type=click.Choice(STAGES, case_sensitive=True),
     help='Target of config files',
     )
+@click.option(
+    '--project', '-p', default="",
+    help='Name of the project, if omitted all projects will be copied.',
+    )
 @click.option('--clean-up', '-c', is_flag=True, default=False,
     help='Clean up files on target side that do not exist as source',
     show_default=True
@@ -341,7 +345,7 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terrag
     help='Working directory, when omitted the current directory is used',
     )
 @click.version_option(version=__version__)
-def deploy(source_domain, source_stage, target_domain, target_stage, verbose, dry_run, clean_up, include_lock_file, working_dir):
+def deploy(source_domain, source_stage, target_domain, target_stage, project, verbose, dry_run, clean_up, include_lock_file, working_dir):
     """ Deploys the terragrunt config files from one stage to another (and possibly to a different domain) """
 
     check_latest_version()
@@ -352,6 +356,7 @@ def deploy(source_domain, source_stage, target_domain, target_stage, verbose, dr
         source_stage=source_stage,
         target_domain=target_domain,
         target_stage=target_stage,
+        project=project,
         dry_run=dry_run,
         clean_up=clean_up,
         include_lock_file=include_lock_file,
