@@ -494,7 +494,10 @@ class TgWrap():
         if not ts_validation_successful:
             raise Exception("Terrasafe validation failed on one or more projects")
 
-    def deploy(self, dry_run, clean_up, include_lock_file, working_dir, source_stage, target_stage, source_domain="", target_domain=""):
+    def deploy(
+        self, dry_run, clean_up, include_lock_file, working_dir, 
+        source_stage, target_stage, source_domain, target_domain, project,
+        ):
         """ Deploys the terragrunt config files from one stage to another (and possibly to a different domain) """
     
         if target_domain and not source_domain:
@@ -509,21 +512,22 @@ class TgWrap():
         # do we have a working dir?
         working_dir = working_dir if working_dir else os.getcwd()
         # the domains will be ignored when omitted as input
-        source_path = os.path.join(working_dir, source_domain, source_stage, '')
-        target_path = os.path.join(working_dir, target_domain, target_stage, '')
+        source_path = os.path.join(working_dir, source_domain, source_stage, project, '')
+        target_path = os.path.join(working_dir, target_domain, target_stage, project, '')
 
         # Check if source exists
         if not self.is_installed('rsync'):
             self.printer.error("'rsync' seems not installed. Cannot continue")
         elif not os.path.exists(source_path):
-            self.printer.error(f"Could not find stage {source_stage} in path {working_dir}. Cannot continue.")
+            self.printer.error(f"Could not find {source_stage}/{project} in path {working_dir}. Cannot continue.")
             if source_domain:
                 self.printer.error(
-                    "Please ensure you are in the directory where your DLZs are located, or use --working-dir option"
+                    "Please ensure you are in the directory that contains your landing zones, " + \
+                    "or use --working-dir option"
                 )
             else:
                 self.printer.error(
-                    "Please ensure you are in the root of your DLZ, or use --working-dir option"
+                    "Please ensure you are in the root of your landing zone, or use --working-dir option"
                 )
         else:
             self.printer.verbose(f"Copying config: {source_path} => {target_path}")
@@ -536,7 +540,7 @@ class TgWrap():
 
             dry_run_stmt = '--dry-run' if dry_run else ''
             clean_stmt   = '--delete' if clean_up else ''
-            env_file_stmt   = "--exclude='env.hcl" if source_stage != target_stage else "--include='env.hcl"
+            env_file_stmt   = "--exclude='env.hcl'" if source_stage != target_stage else "--include='env.hcl'"
             lock_file_stmt  = "--include='.terraform.lock.hcl'" if include_lock_file \
                 else "--exclude='.terraform.lock.hcl'"
 
@@ -544,6 +548,7 @@ class TgWrap():
                 f"--include='terragrunt.hcl' {lock_file_stmt} {env_file_stmt} " + \
                 "--exclude='.terragrunt-cache/' --exclude='.terraform/' " + \
                 "--exclude='terragrunt-debug.tfvars.json' --exclude=planfile " + \
+                "--exclude='.DS_Store' " + \
                 f"{source_path} {target_path}"
 
             cmd = re.sub(' +', ' ', cmd)
